@@ -69,10 +69,6 @@
 #include <sys/select.h>
 #endif /* HAVE_SELECT_H */
 
-#if HAVE_POLL_H
-#include <poll.h>
-#endif /* HAVE_POLL_H */
-
 #if HAVE_FCNTL_H
 #include <fcntl.h>
 #endif /* HAVE_FCNTL_H */
@@ -89,6 +85,7 @@
 
 #include <freetds/tds.h>
 #include <freetds/utils/string.h>
+#include <freetds/utils/nosigpipe.h>
 #include <freetds/tls.h>
 #include <freetds/replacements.h>
 
@@ -109,22 +106,6 @@ static void tds_check_cancel(TDSCONNECTION *conn);
  * @{ 
  */
 
-#ifdef _WIN32
-int
-tds_socket_init(void)
-{
-	WSADATA wsadata;
-
-	return WSAStartup(MAKEWORD(2, 2), &wsadata);
-}
-
-void
-tds_socket_done(void)
-{
-	WSACleanup();
-}
-#endif
-
 #if !defined(SOL_TCP) && (defined(IPPROTO_TCP) || defined(_WIN32))
 /* fix incompatibility between MS headers */
 # ifndef IPPROTO_TCP
@@ -155,10 +136,6 @@ tds_socket_done(void)
 #define USE_NODELAY 1
 #endif
 
-#ifndef __APPLE__
-#undef SO_NOSIGPIPE
-#endif
-
 /**
  * Set socket to non-blocking
  * @param sock socket to set
@@ -371,7 +348,8 @@ TDSERRNO
 tds_open_socket(TDSSOCKET *tds, struct addrinfo *addr, unsigned int port, int timeout, int *p_oserr)
 {
 	TDSCONNECTION *conn = tds->conn;
-	int len, i;
+	size_t len, i;
+	int oserr;
 	TDSERRNO tds_error;
 	struct addrinfo *curr_addr;
 	struct pollfd *fds;
@@ -480,12 +458,12 @@ tds_open_socket(TDSSOCKET *tds, struct addrinfo *addr, unsigned int port, int ti
 		}
 		tds_error = TDSECONN;
 		rc = poll(fds, len, poll_timeout);
-		i = sock_errno; /* save to avoid overrides */
+		oserr = sock_errno; /* save to avoid overrides */
 		curr_time = tds_gettime_ms();
 
 		/* error */
 		if (rc < 0) {
-			*p_oserr = i;
+			*p_oserr = oserr;
 			if (*p_oserr == TDSSOCK_EINTR)
 				continue;
 			goto exit;
@@ -529,7 +507,8 @@ exit:
 		tds->state = TDS_IDLE;
 	}
 
-	while (--len >= 0) {
+	while (len > 0) {
+		--len;
 		if (!TDS_IS_SOCKET_INVALID(fds[len].fd))
 			CLOSESOCKET(fds[len].fd);
 	}
@@ -669,6 +648,8 @@ tds_select(TDSSOCKET * tds, unsigned tds_sel, int timeout_seconds)
 
 			switch (sock_errno) {
 			case TDSSOCK_EINTR:
+			case EAGAIN:
+			case TDSSOCK_EINPROGRESS:
 				/* FIXME this should be global maximun, not loop one */
 				seconds += poll_seconds;
 				break;	/* let interrupt handler be called */
@@ -681,7 +662,10 @@ tds_select(TDSSOCKET * tds, unsigned tds_sel, int timeout_seconds)
 			}
 		}
 
-		assert(rc == 0 || (rc < 0 && sock_errno == TDSSOCK_EINTR));
+		assert(rc == 0 || (rc < 0 && (sock_errno == TDSSOCK_EINTR ||
+					      sock_errno == EAGAIN ||
+					      sock_errno == TDSSOCK_EINPROGRESS
+					      )));
 
 		if (tds_get_ctx(tds) && tds_get_ctx(tds)->int_handler) {	/* interrupt handler installed */
 			/*
@@ -702,7 +686,7 @@ tds_select(TDSSOCKET * tds, unsigned tds_sel, int timeout_seconds)
 				return 0;
 			default:
 				tdsdump_log(TDS_DBG_NETWORK, 
-					"tds_select: invalid interupt handler return code: %d\n", timeout_action);
+					"tds_select: invalid interrupt handler return code: %d\n", timeout_action);
 				return -1;
 			}
 		}
@@ -1035,7 +1019,7 @@ tds_goodwrite(TDSSOCKET * tds, const unsigned char *buffer, size_t buflen)
 }
 
 void
-tds_socket_flush(TDS_SYS_SOCKET sock)
+tds_socket_flush(TDS_SYS_SOCKET sock TDS_UNUSED)
 {
 #ifdef USE_CORK
 	int opt;
